==> theia-0.1.8.15-py3-none-any.whl: theia/aws/containers/k8s/autoscaling.py <==
import pulumi
import base64

from pulumi_aws import autoscaling
from pulumi.output import Output

from dataclasses import field
from pydantic.dataclasses import dataclass, ConfigDict
from typing import List, Mapping, Optional, Literal

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia.definitions import THEIA_VERSION
from theia._registry import StackRegistry, GlobalTags

logger = Logger("autoscaling")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class AutoScalingGroupSettings:
    availability_zones: Optional[str | Output[str]] = None
    desired_capacity: Optional[str | Output[str]] = None
    max_size: Optional[str | Output[str]] = None
    min_size: Optional[str | Output[str]] = None
    launch_template_id: Optional[str | Output[str]] = None
    launch_template_version: Optional[str | Output[str]] = None
    subnet_ids: Optional[List[str | Output[str]]] = None


class AutoScalingGroup:
    def __new__(
        cls,
        resource_name: str,
        tags: Optional[Mapping[str, str]] = None,
        settings: Optional[AutoScalingGroupSettings] = AutoScalingGroupSettings(),
        opts: Optional[ResourceOptions] = None,
    ) -> autoscaling.Group:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | name | GlobalTags.get()
        if tags:
            merged_tags = tags | merged_tags

        group_args = autoscaling.GroupArgs(
            availability_zones=settings.availability_zones,
            desired_capacity=settings.desired_capacity,
            max_size=settings.max_size,
            min_size=settings.min_size,
            launch_template=(
                None
                if not settings.launch_template_id
                else autoscaling.GroupLaunchTemplateArgs(
                    id=settings.launch_template_id,
                    version="$Latest" if not settings.launch_template_version else settings.launch_template_version,
                )
            ),
            vpc_zone_identifiers=settings.subnet_ids,
            tags=merged_tags,
        )

        group = autoscaling.Group(resource_name, name=resource_name, args=group_args, opts=opts)

        pulumi.export(
            f"autoscaling-group---{resource_name}",
            {
                "arn": group.arn,
                "id": group.id,
            },
        )

        return group

    @staticmethod
    def import_(stack: str, resource_name: str) -> autoscaling.Group:
        stack_ref = StackRegistry.get(stack_name=stack)
        group = stack_ref.get_output(name=f"autoscaling-group---{resource_name}")
        return autoscaling.Group.get(resource_name=resource_name, id=group["id"])

==> theia-0.1.8.17-py3-none-any.whl: theia/aws/containers/k8s/autoscaling.py <==
import pulumi

from pulumi_aws import autoscaling
from pulumi.output import Output

from pydantic.dataclasses import dataclass, ConfigDict
from typing import List, Mapping, Optional

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia.definitions import THEIA_VERSION
from theia._registry import StackRegistry, GlobalTags

logger = Logger("autoscaling")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class AutoScalingGroupSettings:
    availability_zones: Optional[List[str | Output[str]]] = None
    desired_capacity: Optional[str | Output[str]] = None
    max_size: Optional[str | Output[str]] = None
    min_size: Optional[str | Output[str]] = None
    launch_template_id: Optional[str | Output[str]] = None
    launch_template_version: Optional[str | Output[str]] = None
    subnet_ids: Optional[List[str | Output[str]]] = None
    propogate_tags_at_launch: Optional[bool] = True
    health_check_grace_period: Optional[int] = None
    target_group_arns: Optional[List[str | Output[str]]] = None


class AutoScalingGroup:
    def __new__(
        cls,
        resource_name: str,
        tags: Optional[Mapping[str, str]] = None,
        settings: Optional[AutoScalingGroupSettings] = AutoScalingGroupSettings(),
        opts: Optional[ResourceOptions] = None,
    ) -> autoscaling.Group:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | name | GlobalTags.get()
        if tags:
            merged_tags = tags | merged_tags

        group_args = autoscaling.GroupArgs(
            availability_zones=settings.availability_zones,
            desired_capacity=settings.desired_capacity,
            max_size=settings.max_size,
            min_size=settings.min_size,
            health_check_grace_period=settings.health_check_grace_period,
            vpc_zone_identifiers=settings.subnet_ids,
            target_group_arns=settings.target_group_arns,
            launch_template=(
                None
                if not settings.launch_template_id
                else autoscaling.GroupLaunchTemplateArgs(
                    id=settings.launch_template_id,
                    version="$Latest" if not settings.launch_template_version else settings.launch_template_version,
                )
            ),
            tags=[
                autoscaling.GroupTagArgs(key=key, value=value, propagate_at_launch=settings.propogate_tags_at_launch)
                for key, value in merged_tags.items()
            ],
        )

        group = autoscaling.Group(resource_name, name=resource_name, args=group_args, opts=opts)

        pulumi.export(
            f"autoscaling-group---{resource_name}",
            {
                "arn": group.arn,
                "id": group.id,
            },
        )

        return group

    @staticmethod
    def import_(stack: str, resource_name: str) -> autoscaling.Group:
        stack_ref = StackRegistry.get(stack_name=stack)
        group = stack_ref.get_output(name=f"autoscaling-group---{resource_name}")
        return autoscaling.Group.get(resource_name=resource_name, id=group["id"])
